@@ -944,9 +944,12 @@ class SMTOtuApi
     const CMD_set_osu_address = 'OTU:SWITCH:OSUS:ADDRESS %s';
     const CMD_set_osx_address = 'OTU:SWITCH:OSXJ:ADDRESS %s';
     const CMD_scan_osu = 'OTU:SWITCH:OSUJ:SCAN?';   // on ne gere plus les OSUs Dicon
+    const CMD_get_osuj_desc = 'OTU:SWITCH:OSUJ:DESC? %s';
     const CMD_is_osu_present = 'OTU:SWITCH:OSUS:PRESENT? %s,%s';//N_Osus,ALL/JDSU/DICON     
      
     const CMD_get_osu_desc = 'OTU:SWITCH:OSUS:DESC? %s';
+    const CMD_get_osuj_idn = 'OTU:SWITCH:DEBUG:JDSU:IDN? %d';
+    const CMD_get_osuj_select = 'OTU:SWITCH:DEBUG:SELECT EXT';
     const CMD_get_osu_ports = 'OTU:SWITCH:OSUS:PORT? %s';    //OSU1/OSU2/...OSU31
     const CMD_get_bigtopo = 'OTU:SWITCH:CONF:BIGT? %d';    //0/1... // Macroswitchid
     const CMD_set_bigtopo = 'OTU:SWITCH:CONF:BIGT %d, %s';    //0/1... forMacroswitchid, TRUE/FALSE
@@ -963,6 +966,9 @@ class SMTOtuApi
     const CMD_switch_detect_SerialNum = 'OTU:SWITCH:DETECT:SER? %d,%s'; //0,INT/OSU1/OSU2 ... OSU31
     const CMD_switch_detect_calib_SerialNum = 'OTU:SWITCH:CONFIG:DETECT:SER? %d,%s'; //0,INT/OSU1/OSU2 ... ... OSU31//Detection from calibration
     const CMD_get_switch_ports = 'OTU:SWITCH:CONF:PORT? %d';    //0/1/2/3/...31
+    const CMD_get_switch_jdsu_idn = 'OTU:SWITCH:OSXJdsu:IDN? %d';
+    const CMD_switch_detect_Serial_Number_List = 'OTU:SWITCH:OSXJdsu:DETSERial?';
+    const CMD_switch_config_Serial_Number_List = 'OTU:SWITCH:OSXJdsu:CONFSERial?';
     
     //OTAU NEW FUNCTIONS to handle big configurations of ROTAUs
     const CMD_compare_switches = 'OTU:SWITCH:COMPAR:MACRO? %d';//0/1... for Macroswitchid, returns SAME,DIFF,MISSCONF,MISSDET
@@ -2176,6 +2182,14 @@ class SMTOtuApi
     	}
     }
     
+    const CMD_RESET_FIREWALL_CONTENT = "OTU:SYSTEM:EFIREWALL:CUSTReset";    
+    /**
+     * Get firewall reset custom firewall content
+     */
+    static function getFirewallResetCustomContentCommand()
+    {
+    	return self::CMD_RESET_FIREWALL_CONTENT;
+    }
     
     const CMD_SET_FIREWALL_OLD = "OTU:SYSTEM:WWW %s";
     const CMD_GET_FIREWALL_OLD = "OTU:SYSTEM:WWW?";
@@ -2455,6 +2469,18 @@ class SMTOtuApi
     	return sprintf( self::CMD_set_otu_mon_mode, $mode);
     }
     
+    const CMD_is_ntp_enabled= "OTU:API:CONF:NTP:ENABLE?";
+    function getNtpActive()
+    {
+    	return self::CMD_is_ntp_enabled;
+    }
+    
+    const CMD_get_ntp_sync= "OTU:API:CONF:NTP:SYNC";
+    function getNtpSync()
+    {
+    	return self::CMD_get_ntp_sync;
+    }
+
     ////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
     //
     // API
