@@ -151,15 +151,21 @@ class SMTApiOtuService extends SMTService implements SMTIService
 				try 
 				{
 					$snmpInfo = $this->sendReceive( SMTOtuApi::getSnmpConfig($id) );
-					list( $id, $address, $community, $port ) = explode(",", $snmpInfo);
-					$snmp = new SMTApiSnmpDto();
-					$snmp->setId( trim($id) );
-					$snmp->setAddress(trim($address) );				
-					$snmp->setCommunity(trim($community));
-					$snmp->setPort(trim($port));
-					if ( $snmp->isConfigValid() )
+					if ( strlen($snmpInfo) > 0 )
 					{
-						$snmpListDto->addSnmpManager($snmp);
+						list( $id, $address, $community, $port ) = explode(",", $snmpInfo);
+						if ( strlen($id) > 0 )
+						{
+							$snmp = new SMTApiSnmpDto();
+							$snmp->setId( trim($id) );
+							$snmp->setAddress(trim($address) );				
+							$snmp->setCommunity(trim($community));
+							$snmp->setPort(trim($port));
+							if ( $snmp->isConfigValid() )
+							{
+								$snmpListDto->addSnmpManager($snmp);
+							}
+						}
 					}
 				}
 				catch(\Exception $ex)
@@ -298,7 +304,12 @@ class SMTApiOtuService extends SMTService implements SMTIService
 			{
 				try
 				{
-					$this->sendReceive( SMTOtuApi::getSnmpConfig($id) );
+					$snmpInfo = $this->sendReceive( SMTOtuApi::getSnmpConfig($id) );
+					if ( strlen($snmpInfo) <= 0 )
+					{
+						$testStatusDto->setStatus(SMTApiStatusDto::INVALID_SNMP_MANAGER);
+						SMTHttpResponse::handleApiError( $this->getContext(), SMTRestException::BAD_REQUEST, $testStatusDto->getStatus(), 'No SNMP manager found with id  '.$id);
+					}
 				}
 				catch(\Exception $ex)
 				{
@@ -584,6 +595,11 @@ class SMTApiOtuService extends SMTService implements SMTIService
 				$userToSend->setNewLogin( SMTUserUtil::getSmartOTUGuestLogin() );
 				$userToSend->setNewPassword('***');
 			}
+			else 
+			{
+				$userToSend->setNewLogin('');
+				$userToSend->setNewPassword('');
+			}
 		}
 		catch ( \Exception $e )
 		{
