@@ -243,6 +243,22 @@ class SMTEthernetDto extends SMTRwDto
     	return $this->enhancedSecurity;
     }
     
+    public function stripHtmlTags()
+    {
+    	if ( $this->ipv4!= NULL )
+    	{
+    		$this->ipv4->stripHtmlTags();
+    	}
+    	if ( $this->ipv6 != NULL )
+    	{
+    		$this->ipv6->stripHtmlTags();
+    	}
+    	if ( $this->customFirewall != NULL )
+    	{
+    		$this->customFirewall->stripHtmlTags();
+    	}
+    }
+    
     /**
      * Serialize as Json data the object.<br>
      *
@@ -274,7 +290,9 @@ class SMTEthernetDto extends SMTRwDto
      */
     static function getInstance( array &$json_array )
     {
-    	return self::forge( get_class(), $json_array );
-    }    
+    	$instance = self::forge( get_class(), $json_array );
+    	$instance->stripHtmlTags();
+    	return $instance;
+    }
 }
 ?>
\ No newline at end of file
