@@ -303,43 +303,42 @@ class SMTEthernetService extends SMTService implements SMTIService
     	try
     	{    	   
     	    $ethernetConfig = SMTEthernetDto::getInstance( $request_data );
+    	    
     	    //pas de changement du firewall en mode ONMSi
-    	    if ( !SMTOtuMode::isONMSi() )
-    	    {
+    	    //if ( !SMTOtuMode::isONMSi() )
     	    	//Dans le cas d'une config de firewall custom
-	    	    if ( strcasecmp( $ethernetConfig->getFirewallMode(), SMTFirewall::FIREWALL_CUSTOM) == 0 )
-	    	    {
-	    	        $customFirewallConfig = $ethernetConfig->getCustomFirewall();
-	    	        //if firewall config is set
-	    	        if ( isset ($customFirewallConfig) && $customFirewallConfig != NULL )
-	    	        {
-	    	            $firewall = new SMTFirewall();
-	    	            $firewall->setContext( $this->getContext() );
-	    	            //si la config du firewall n'est pas vide
-	    	            if ( count ($customFirewallConfig->getCustomFirewall() ) > 0 )
-	    	            {
-	    	                $firewall->saveConfig($customFirewallConfig->getCustomFirewall());
-	    	                //if config save fails, don't change to custom firewall (only change when everything got right)
-	    	                $this->setFirewallMode( SMTFirewall::FIREWALL_CUSTOM );
-	    	            }
-	    	            else
-	    	            {
-	    	                $this->getContext()->getLogger()->trace("customFirewallConfig empty", SMTLogger::ERROR, __FILE__,__METHOD__,__LINE__ );
-	    	            }
-	    	        }
-	    	        else
-	    	        {
-	    	            //check that custom firewall config file exists, before switching to custom firewall
-	    	            $firewall = new SMTFirewall();
-	    	            $firewall->setContext( $this->getContext() );
-	    	            $firewall->readCustomFirewallConfig();
-	    	            $this->setFirewallMode( SMTFirewall::FIREWALL_CUSTOM );
-	    	        }
-	    	    }
-	    	    else
-	    	    {
-	    	        $this->setFirewallMode( $ethernetConfig->getFirewallMode() );
-	    	    }
+    	    if ( strcasecmp( $ethernetConfig->getFirewallMode(), SMTFirewall::FIREWALL_CUSTOM) == 0 )
+    	    {
+    	        $customFirewallConfig = $ethernetConfig->getCustomFirewall();
+    	        //if firewall config is set
+    	        if ( isset ($customFirewallConfig) && $customFirewallConfig != NULL )
+    	        {
+    	            $firewall = new SMTFirewall();
+    	            $firewall->setContext( $this->getContext() );
+    	            //si la config du firewall n'est pas vide
+    	            if ( count ($customFirewallConfig->getCustomFirewall() ) > 0 )
+    	            {
+    	                $firewall->saveConfig($customFirewallConfig->getCustomFirewall());
+    	                //if config save fails, don't change to custom firewall (only change when everything got right)
+    	                $this->setFirewallMode( SMTFirewall::FIREWALL_CUSTOM );
+    	            }
+    	            else
+    	            {
+    	                $this->getContext()->getLogger()->trace("customFirewallConfig empty", SMTLogger::ERROR, __FILE__,__METHOD__,__LINE__ );
+    	            }
+    	        }
+    	        else
+    	        {
+    	            //check that custom firewall config file exists, before switching to custom firewall
+    	            $firewall = new SMTFirewall();
+    	            $firewall->setContext( $this->getContext() );
+    	            $firewall->readCustomFirewallConfig();
+    	            $this->setFirewallMode( SMTFirewall::FIREWALL_CUSTOM );
+    	        }
+    	    }
+    	    else
+    	    {
+    	        $this->setFirewallMode( $ethernetConfig->getFirewallMode() );
     	    }
 	    }
 	    catch ( \Exception $e )
@@ -510,6 +509,30 @@ class SMTEthernetService extends SMTService implements SMTIService
     	return $customFirewallConfig->getJsonData();
     }
     
+    /**
+     * Reset custom firewall content file with default content
+     *
+     * @url POST /firewall/resetcustom
+     *
+     * @access protected
+     * @class SMTAccessControl {@requires install}
+     */
+    function resetCustomFileContent()
+    {
+    	try
+    	{
+    		$firewall = new SMTFirewall();
+    		$firewall->setContext( $this->getContext() );
+    		$firewall->resetCustomFileContent();
+    	}
+    	catch ( \Exception $e )
+    	{
+    		$this->handleException($e);
+    	}
+    	
+    	return self::RESULT_OK;
+    }
+    
     /**
      * return whether the enhanced security mode is active
      *
