@@ -99,9 +99,16 @@ abstract class SMTMacroSwitch
 
     /**
      * Retrieve INT switch and set switch decoder
-     */    
+     */
     abstract protected function retrieveInternal();
     
+    /**
+     * retrieve external switches serial numbers
+     */
+    protected function updateOSXSerialNumbers()
+    {    	
+    }
+    
     /**
      * Return the number of output ports
      * 
