@@ -96,7 +96,35 @@ class SMTMacroSwitchConf extends SMTMacroSwitch
                 //$ports = $this->switchManager->sendReceive( sprintf( SMTOtuApi::CMD_get_switch_ports, parent::INTERNAL_POSITION ) );
             }
         }                
-    }        
+    }
+    
+    /**
+     * Retrieve internal switch and build Dto
+     *
+     */
+    protected function updateOSXSerialNumbers()
+    {
+    	$result = trim( $this->socket->sendReceive( SMTOtuApi::CMD_switch_config_Serial_Number_List) );
+    	if ( $result != "" )
+    	{
+    		$serialNumberList = explode(',', $result);
+    		if (is_array($serialNumberList) && count($serialNumberList) > 0 )
+    		{
+	    		foreach ( $this->switchesDto as &$switchDto) 
+	    		{
+	    			if ($switchDto->getIndex() == self::OSU_DISTRIBUTOR_INDEX)
+	    			{
+	    				$switchDto->setSerialNumber( end($serialNumberList) );
+	    			}
+	    			else if ( $switchDto->getIndex() > 0) 
+	    			{
+	    				//SMTLogger::getInstance()->trace(sprintf("serialNumberList[switchDto->getIndex() - 1]: %d", $serialNumberList[$switchDto->getIndex() - 1]), SMTLogger::INFO);
+	    				$switchDto->setSerialNumber( $serialNumberList[$switchDto->getIndex() - 1] );
+	    			}
+	    		}
+    		}
+    	}
+    }
     
     /**
      * Retrieve internal switch and build the switch Dto
@@ -109,8 +137,9 @@ class SMTMacroSwitchConf extends SMTMacroSwitch
     {
         $macroSwitchConf = new SMTMacroSwitchConf($socket);
         $macroSwitchConf->retrieveGlobal();
-    	$macroSwitchConf->retrieveInternal();    	
+    	$macroSwitchConf->retrieveInternal();
     	$macroSwitchConf->buildSwitchDto( FALSE );
+    	$macroSwitchConf->updateOSXSerialNumbers();
     	
     	return $macroSwitchConf;
     }  
