@@ -88,6 +88,33 @@ class SMTMacroSwitchDet extends SMTMacroSwitch
         }
     }        
     
+    /**
+     * Retrieve internal switch and build Dto
+     *
+     */
+    protected function updateOSXSerialNumbers()
+    {
+    	$result = trim( $this->socket->sendReceive( SMTOtuApi::CMD_switch_detect_Serial_Number_List) );
+    	if ( $result != "" )
+    	{
+    		$serialNumberList = explode(',', $result);
+    		if (is_array($serialNumberList) && count($serialNumberList) > 0)
+    		{
+    			foreach ( $this->switchesDto as &$switchDto)
+    			{
+    				if ($switchDto->getIndex() == self::OSU_DISTRIBUTOR_INDEX)
+    				{
+    					$switchDto->setSerialNumber( end($serialNumberList) );
+    				}
+    				else if ( $switchDto->getIndex() > 0)
+    				{
+    					$switchDto->setSerialNumber( $serialNumberList[$switchDto->getIndex() - 1] );
+    				}
+    			}
+    		}
+    	}
+    }
+    
     /**
      * Retrieve internal switch and build the switch Dto
      * 
@@ -99,8 +126,9 @@ class SMTMacroSwitchDet extends SMTMacroSwitch
     {
         $macroSwitchDet = new SMTMacroSwitchDet( $socket );
         $macroSwitchDet->retrieveGlobal();
-    	$macroSwitchDet->retrieveInternal();    	  
+    	$macroSwitchDet->retrieveInternal();
     	$macroSwitchDet->buildSwitchDto( TRUE );
+    	$macroSwitchDet->updateOSXSerialNumbers();
     	
     	return $macroSwitchDet;
     }    
