@@ -44,6 +44,7 @@ class SMTSwitchManager extends SMTServiceHelper implements SMTISerializable
 	
 	const OSX_POWER_ON = "ON";
 	const OSX_POWER_OFF = "OFF";
+	const INVALID_PORT_STRING = '-> 0';
 	
     /**
      * For smartOtu, no ROTAU can be used => macros switch id = 0
@@ -226,7 +227,7 @@ class SMTSwitchManager extends SMTServiceHelper implements SMTISerializable
      *
      * @return list of osxs full scan description
      */
-    function fullScan()
+    function fullScanLegacy()
     {
     	$osxList = new SMTOsxListDto();
     	
@@ -238,11 +239,17 @@ class SMTSwitchManager extends SMTServiceHelper implements SMTISerializable
     	{    		
     		if( intval($osx_address_array[$i]) > 0 )
     		{
-    			$osxDesc = $this->sendReceive( sprintf(SMTOtuApi::CMD_get_osu_desc, $osx_address_array[$i]) );
-    			try 
+    			$osxDesc = "";
+    			try
     			{
+    				// si an OSX is found during scan but desc fails, don't throw exception, to avoid to loose all the scan result
+    				$osxDesc = $this->sendReceive( sprintf(SMTOtuApi::CMD_get_osuj_desc, $osx_address_array[$i]) );
     				$ports = $this->sendReceive( sprintf(SMTOtuApi::CMD_get_osu_ports, $osx_address_array[$i]) );
-	    		}
+    				if ( substr( $ports, -strlen( self::INVALID_PORT_STRING ) ) == self::INVALID_PORT_STRING)
+    				{
+    					$ports = "";
+    				}
+    			}
 	    		//ports are retrieved from detection and can fail
 	    		catch ( \Exception $e )
 	    		{
@@ -271,6 +278,60 @@ class SMTSwitchManager extends SMTServiceHelper implements SMTISerializable
     	return $osxList;
     }
     
+    /**
+     * Full scan of osxs limited to *idn?
+     *
+     * @return list of osxs full scan description
+     */
+    function fullScan()
+    {
+    	$osxList = new SMTOsxListDto();
+    	
+    	for ($i=1; $i<= SMTMacroSwitch::OSU_DISTRIBUTOR_INDEX; $i++)
+    	{
+    		$osxDesc = '';
+    		try
+    		{
+    			$osxDesc = $this->sendReceive( sprintf(SMTOtuApi::CMD_get_switch_jdsu_idn, $i) );
+    			$osxDesc= preg_replace('/[[:^print:]]/', '', $osxDesc);
+    			try 
+    			{
+	    			$ports = $this->sendReceive( sprintf(SMTOtuApi::CMD_get_osu_ports, $i) );
+	    			if ( substr( $ports, -strlen( self::INVALID_PORT_STRING ) ) == self::INVALID_PORT_STRING)
+	    			{
+	    				$ports = '';
+	    			}
+    			}
+    			catch(\Exception $ex )
+    			{
+    				$ports = '';
+    			}
+    			$osx = new SMTOsxDto();
+    			$osx->setIndex( $i );
+    			$osx->setDescription($osxDesc);
+    			$osx->setPorts($ports);
+    			$osxList->addOsx($osx);
+    		}
+    		//ports are retrieved from detection and can fail
+    		catch ( \Exception $e )
+    		{
+    			SMTLogger::getInstance()->traceException($e);
+    		}
+    	}
+    	
+    	//retrieve big topology
+    	$osxList->setIsBigTopology($this->isBigTopology());
+    	
+    	SMTMemoryManager::deleteAll( SMTOsxListDto::getClass() );
+    	
+    	// save scan in memory
+    	$osxList->save();
+    	
+    	// force next detection
+    	SMTOtuStatusCacheDto::setSwitchDetectedOnce(FALSE);
+    	
+    	return $osxList;
+    }
     /**
      * Show an OSX
      * 
