@@ -164,7 +164,7 @@ function checkBackup($filename, SMTContext $context)
 /////////////////////////////////////////////////////////////////////////////////////////
 function checkPatchExtension($filename)
 {
-	return SMTUtil::startsWith($filename, 'path_otu') && SMTUtil::endsWith( $filename, '.tar.gz');
+	return SMTUtil::startsWith($filename, 'patch_otu') && SMTUtil::endsWith( $filename, '.tar.gz');
 }
 function checkPatch($filename, SMTContext $context)
 {
