@@ -8,6 +8,7 @@
 LPORT=$1
 IP=$2
 DPORT=$3
+SSHPORT=$4
 TMP_SSH_RESULT="/tmp/ssh.result"
 TMP_SSH_PID="/tmp/ssh.pid"
 
@@ -23,7 +24,7 @@ function usage ()
 
 
 # check for parametres
-if [ $# != 3 ]
+if [ $# != 4 ]
 then
         usage
     exit 1
@@ -34,7 +35,7 @@ rm -f $TMP_SSH_RESULT
 rm -f $TMP_SSH_PID
 
 # lancement et detachement de ssh en mode tunnel, timeout a 15 secondes
-ssh -o ConnectTimeout=$TESTTIMEOUT -L $LPORT:localhost:$DPORT secuser@$IP -N 2> $TMP_SSH_RESULT &
+ssh -p $SSHPORT -o ConnectTimeout=$TESTTIMEOUT -L $LPORT:localhost:$DPORT secuser@$IP -N 2> $TMP_SSH_RESULT &
 
 # get PID as command returned value, and save to file
 PID=$!
