@@ -5,7 +5,7 @@ build_time_vars = {'ABIFLAGS': 'm',
  'AR': 'arm-jdsu-linux-gnueabi-ar',
  'ARCH': 'x86_64',
  'ARFLAGS': 'rc',
- 'ASDLGEN': '/export/home01/buildbot_yocto/worker/morty_eotdrv2/build/eotdrv2/tmp/sysroots/x86_64-linux/usr/bin/python3-native/python3 '
+ 'ASDLGEN': '/mnt/Yocto/dev_morty/eotdrv2/tmp/sysroots/x86_64-linux/usr/bin/python3-native/python3 '
             '../Python-3.5.2/Parser/asdl_c.py',
  'ASDLGEN_FILES': '../Python-3.5.2/Parser/asdl.py '
                   '../Python-3.5.2/Parser/asdl_c.py',
@@ -35,21 +35,21 @@ build_time_vars = {'ABIFLAGS': 'm',
  'CCSHARED': '-fPIC',
  'CFLAGS': '-Wno-unused-result -Wsign-compare -DNDEBUG -g  -O3 -Wall '
            '-Wstrict-prototypes -O2 -pipe -g -feliminate-unused-debug-types '
-           '-fdebug-prefix-map=/export/home01/buildbot_yocto/worker/morty_eotdrv2/build/eotdrv2/tmp/work/cortexa9hf-neon-jdsu-linux-gnueabi/python3/3.5.2-r1.0=/usr/src/debug/python3/3.5.2-r1.0 '
-           '-fdebug-prefix-map=/export/home01/buildbot_yocto/worker/morty_eotdrv2/build/eotdrv2/tmp/sysroots/x86_64-linux= '
-           '-fdebug-prefix-map=/export/home01/buildbot_yocto/worker/morty_eotdrv2/build/eotdrv2/tmp/sysroots/eotdrv2=  '
+           '-fdebug-prefix-map=/mnt/Yocto/dev_morty/eotdrv2/tmp/work/cortexa9hf-neon-jdsu-linux-gnueabi/python3/3.5.2-r1.0=/usr/src/debug/python3/3.5.2-r1.0 '
+           '-fdebug-prefix-map=/mnt/Yocto/dev_morty/eotdrv2/tmp/sysroots/x86_64-linux= '
+           '-fdebug-prefix-map=/mnt/Yocto/dev_morty/eotdrv2/tmp/sysroots/eotdrv2=  '
            '-O2 -pipe -g -feliminate-unused-debug-types '
-           '-fdebug-prefix-map=/export/home01/buildbot_yocto/worker/morty_eotdrv2/build/eotdrv2/tmp/work/cortexa9hf-neon-jdsu-linux-gnueabi/python3/3.5.2-r1.0=/usr/src/debug/python3/3.5.2-r1.0 '
-           '-fdebug-prefix-map=/export/home01/buildbot_yocto/worker/morty_eotdrv2/build/eotdrv2/tmp/sysroots/x86_64-linux= '
-           '-fdebug-prefix-map=/export/home01/buildbot_yocto/worker/morty_eotdrv2/build/eotdrv2/tmp/sysroots/eotdrv2=',
+           '-fdebug-prefix-map=/mnt/Yocto/dev_morty/eotdrv2/tmp/work/cortexa9hf-neon-jdsu-linux-gnueabi/python3/3.5.2-r1.0=/usr/src/debug/python3/3.5.2-r1.0 '
+           '-fdebug-prefix-map=/mnt/Yocto/dev_morty/eotdrv2/tmp/sysroots/x86_64-linux= '
+           '-fdebug-prefix-map=/mnt/Yocto/dev_morty/eotdrv2/tmp/sysroots/eotdrv2=',
  'CFLAGSFORSHARED': '-fPIC',
  'CFLAGS_NODIST': '',
  'CONFIGFILES': 'configure configure.ac acconfig.h pyconfig.h.in '
                 'Makefile.pre.in',
  'CONFIGURE_CFLAGS': '-O2 -pipe -g -feliminate-unused-debug-types '
-                     '-fdebug-prefix-map=/export/home01/buildbot_yocto/worker/morty_eotdrv2/build/eotdrv2/tmp/work/cortexa9hf-neon-jdsu-linux-gnueabi/python3/3.5.2-r1.0=/usr/src/debug/python3/3.5.2-r1.0 '
-                     '-fdebug-prefix-map=/export/home01/buildbot_yocto/worker/morty_eotdrv2/build/eotdrv2/tmp/sysroots/x86_64-linux= '
-                     '-fdebug-prefix-map=/export/home01/buildbot_yocto/worker/morty_eotdrv2/build/eotdrv2/tmp/sysroots/eotdrv2=',
+                     '-fdebug-prefix-map=/mnt/Yocto/dev_morty/eotdrv2/tmp/work/cortexa9hf-neon-jdsu-linux-gnueabi/python3/3.5.2-r1.0=/usr/src/debug/python3/3.5.2-r1.0 '
+                     '-fdebug-prefix-map=/mnt/Yocto/dev_morty/eotdrv2/tmp/sysroots/x86_64-linux= '
+                     '-fdebug-prefix-map=/mnt/Yocto/dev_morty/eotdrv2/tmp/sysroots/eotdrv2=',
  'CONFIGURE_CFLAGS_NODIST': '-Werror=declaration-after-statement',
  'CONFIGURE_CPPFLAGS': '',
  'CONFIGURE_LDFLAGS': '-Wl,-O1 -Wl,--hash-style=gnu -Wl,--as-needed',
@@ -68,7 +68,7 @@ build_time_vars = {'ABIFLAGS': 'm',
                 "'--without-cxx-main' '--with-signal-module' '--enable-shared' "
                 "'--enable-ipv6=yes' 'ac_cv_header_bluetooth_bluetooth_h=no' "
                 "'ac_cv_header_bluetooth_h=no' "
-                "'CROSSPYTHONPATH=/export/home01/buildbot_yocto/worker/morty_eotdrv2/build/eotdrv2/tmp/sysroots/x86_64-linux/usr/lib/python3.5/lib-dynload/' "
+                "'CROSSPYTHONPATH=/mnt/Yocto/dev_morty/eotdrv2/tmp/sysroots/x86_64-linux/usr/lib/python3.5/lib-dynload/' "
                 "'--without-ensurepip' 'build_alias=x86_64-linux' "
                 "'host_alias=arm-jdsu-linux-gnueabi' "
                 "'target_alias=arm-jdsu-linux-gnueabi' "
@@ -77,21 +77,21 @@ build_time_vars = {'ABIFLAGS': 'm',
                 '-fno-inline '
                 "' "
                 "'CFLAGS= -O2 -pipe -g -feliminate-unused-debug-types "
-                '-fdebug-prefix-map=/export/home01/buildbot_yocto/worker/morty_eotdrv2/build/eotdrv2/tmp/work/cortexa9hf-neon-jdsu-linux-gnueabi/python3/3.5.2-r1.0=/usr/src/debug/python3/3.5.2-r1.0 '
-                '-fdebug-prefix-map=/export/home01/buildbot_yocto/worker/morty_eotdrv2/build/eotdrv2/tmp/sysroots/x86_64-linux= '
-                '-fdebug-prefix-map=/export/home01/buildbot_yocto/worker/morty_eotdrv2/build/eotdrv2/tmp/sysroots/eotdrv2= '
+                '-fdebug-prefix-map=/mnt/Yocto/dev_morty/eotdrv2/tmp/work/cortexa9hf-neon-jdsu-linux-gnueabi/python3/3.5.2-r1.0=/usr/src/debug/python3/3.5.2-r1.0 '
+                '-fdebug-prefix-map=/mnt/Yocto/dev_morty/eotdrv2/tmp/sysroots/x86_64-linux= '
+                '-fdebug-prefix-map=/mnt/Yocto/dev_morty/eotdrv2/tmp/sysroots/eotdrv2= '
                 "' 'LDFLAGS=-Wl,-O1 -Wl,--hash-style=gnu -Wl,--as-needed' "
                 "'CPPFLAGS=' 'CPP=arm-jdsu-linux-gnueabi-gcc -E "
                 '  '
                 '-march=armv7-a -marm -mfpu=neon  -mfloat-abi=hard '
                 "-mcpu=cortex-a9 -DNDEBUG -fno-inline' "
-                "'PKG_CONFIG_PATH=/export/home01/buildbot_yocto/worker/morty_eotdrv2/build/eotdrv2/tmp/sysroots/eotdrv2/usr/lib/pkgconfig:/export/home01/buildbot_yocto/worker/morty_eotdrv2/build/eotdrv2/tmp/sysroots/eotdrv2/usr/share/pkgconfig' "
-                "'PKG_CONFIG_LIBDIR=/export/home01/buildbot_yocto/worker/morty_eotdrv2/build/eotdrv2/tmp/sysroots/eotdrv2/usr/lib/pkgconfig'",
+                "'PKG_CONFIG_PATH=/mnt/Yocto/dev_morty/eotdrv2/tmp/sysroots/eotdrv2/usr/lib/pkgconfig:/mnt/Yocto/dev_morty/eotdrv2/tmp/sysroots/eotdrv2/usr/share/pkgconfig' "
+                "'PKG_CONFIG_LIBDIR=/mnt/Yocto/dev_morty/eotdrv2/tmp/sysroots/eotdrv2/usr/lib/pkgconfig'",
  'CONFINCLUDEDIR': '/usr/include',
  'CONFINCLUDEPY': '/usr/include/python3.5m',
  'COREPYTHONPATH': ':plat-linux',
- 'COVERAGE_INFO': '/export/home01/buildbot_yocto/worker/morty_eotdrv2/build/eotdrv2/tmp/work/cortexa9hf-neon-jdsu-linux-gnueabi/python3/3.5.2-r1.0/build/coverage.info',
- 'COVERAGE_REPORT': '/export/home01/buildbot_yocto/worker/morty_eotdrv2/build/eotdrv2/tmp/work/cortexa9hf-neon-jdsu-linux-gnueabi/python3/3.5.2-r1.0/build/lcov-report',
+ 'COVERAGE_INFO': '/mnt/Yocto/dev_morty/eotdrv2/tmp/work/cortexa9hf-neon-jdsu-linux-gnueabi/python3/3.5.2-r1.0/build/coverage.info',
+ 'COVERAGE_REPORT': '/mnt/Yocto/dev_morty/eotdrv2/tmp/work/cortexa9hf-neon-jdsu-linux-gnueabi/python3/3.5.2-r1.0/build/lcov-report',
  'COVERAGE_REPORT_OPTIONS': '--no-branch-coverage --title "CPython lcov '
                             'report"',
  'CPPFLAGS': '-I. -IInclude -I../Python-3.5.2/Include',
@@ -543,7 +543,7 @@ build_time_vars = {'ABIFLAGS': 'm',
  'LIBC': '',
  'LIBDEST': '/usr/lib/python3.5',
  'LIBDIR': '/usr/lib',
- 'LIBFFI_INCLUDEDIR': '/export/home01/buildbot_yocto/worker/morty_eotdrv2/build/eotdrv2/tmp/sysroots/eotdrv2/usr/lib/libffi-3.2.1/include',
+ 'LIBFFI_INCLUDEDIR': '/mnt/Yocto/dev_morty/eotdrv2/tmp/sysroots/eotdrv2/usr/lib/libffi-3.2.1/include',
  'LIBM': '-lm',
  'LIBOBJDIR': 'Python/',
  'LIBOBJS': '',
@@ -602,7 +602,7 @@ build_time_vars = {'ABIFLAGS': 'm',
  'OPCODETARGETS_H': '\\',
  'OPCODE_H': '../Python-3.5.2/Include/opcode.h',
  'OPCODE_H_DIR': '../Python-3.5.2/Include',
- 'OPCODE_H_GEN': '/export/home01/buildbot_yocto/worker/morty_eotdrv2/build/eotdrv2/tmp/sysroots/x86_64-linux/usr/bin/python3-native/python3  '
+ 'OPCODE_H_GEN': '/mnt/Yocto/dev_morty/eotdrv2/tmp/sysroots/x86_64-linux/usr/bin/python3-native/python3  '
                  '../Python-3.5.2/Tools/scripts/generate_opcode_h.py '
                  '../Python-3.5.2/Lib/opcode.py '
                  '../Python-3.5.2/Include/opcode.h',
@@ -642,32 +642,32 @@ build_time_vars = {'ABIFLAGS': 'm',
  'PYTHONFRAMEWORKINSTALLDIR': '',
  'PYTHONFRAMEWORKPREFIX': '',
  'PYTHONPATH': ':plat-linux',
- 'PYTHON_FOR_BUILD': '_PYTHON_PROJECT_BASE=/export/home01/buildbot_yocto/worker/morty_eotdrv2/build/eotdrv2/tmp/work/cortexa9hf-neon-jdsu-linux-gnueabi/python3/3.5.2-r1.0/build '
+ 'PYTHON_FOR_BUILD': '_PYTHON_PROJECT_BASE=/mnt/Yocto/dev_morty/eotdrv2/tmp/work/cortexa9hf-neon-jdsu-linux-gnueabi/python3/3.5.2-r1.0/build '
                      '_PYTHON_HOST_PLATFORM=$(_PYTHON_HOST_PLATFORM) '
-                     'PYTHONPATH=/export/home01/buildbot_yocto/worker/morty_eotdrv2/build/eotdrv2/tmp/sysroots/x86_64-linux/usr/lib/python3.5/lib-dynload/:/export/home01/buildbot_yocto/worker/morty_eotdrv2/build/eotdrv2/tmp/work/cortexa9hf-neon-jdsu-linux-gnueabi/python3/3.5.2-r1.0/build/build/lib.linux-arm-3.5:/export/home01/buildbot_yocto/worker/morty_eotdrv2/build/eotdrv2/tmp/work/cortexa9hf-neon-jdsu-linux-gnueabi/python3/3.5.2-r1.0/Python-3.5.2/Lib:/export/home01/buildbot_yocto/worker/morty_eotdrv2/build/eotdrv2/tmp/work/cortexa9hf-neon-jdsu-linux-gnueabi/python3/3.5.2-r1.0/Python-3.5.2/Lib/plat-linux '
+                     'PYTHONPATH=/mnt/Yocto/dev_morty/eotdrv2/tmp/sysroots/x86_64-linux/usr/lib/python3.5/lib-dynload/:/mnt/Yocto/dev_morty/eotdrv2/tmp/work/cortexa9hf-neon-jdsu-linux-gnueabi/python3/3.5.2-r1.0/build/build/lib.linux-arm-3.5:/mnt/Yocto/dev_morty/eotdrv2/tmp/work/cortexa9hf-neon-jdsu-linux-gnueabi/python3/3.5.2-r1.0/Python-3.5.2/Lib:/mnt/Yocto/dev_morty/eotdrv2/tmp/work/cortexa9hf-neon-jdsu-linux-gnueabi/python3/3.5.2-r1.0/Python-3.5.2/Lib/plat-linux '
                      'python3.5',
  'PYTHON_HEADERS': '\\',
  'PYTHON_OBJS': '\\',
  'PY_CFLAGS': '-Wno-unused-result -Wsign-compare -DNDEBUG -g  -O3 -Wall '
               '-Wstrict-prototypes -O2 -pipe -g -feliminate-unused-debug-types '
-              '-fdebug-prefix-map=/export/home01/buildbot_yocto/worker/morty_eotdrv2/build/eotdrv2/tmp/work/cortexa9hf-neon-jdsu-linux-gnueabi/python3/3.5.2-r1.0=/usr/src/debug/python3/3.5.2-r1.0 '
-              '-fdebug-prefix-map=/export/home01/buildbot_yocto/worker/morty_eotdrv2/build/eotdrv2/tmp/sysroots/x86_64-linux= '
-              '-fdebug-prefix-map=/export/home01/buildbot_yocto/worker/morty_eotdrv2/build/eotdrv2/tmp/sysroots/eotdrv2=  '
+              '-fdebug-prefix-map=/mnt/Yocto/dev_morty/eotdrv2/tmp/work/cortexa9hf-neon-jdsu-linux-gnueabi/python3/3.5.2-r1.0=/usr/src/debug/python3/3.5.2-r1.0 '
+              '-fdebug-prefix-map=/mnt/Yocto/dev_morty/eotdrv2/tmp/sysroots/x86_64-linux= '
+              '-fdebug-prefix-map=/mnt/Yocto/dev_morty/eotdrv2/tmp/sysroots/eotdrv2=  '
               '-O2 -pipe -g -feliminate-unused-debug-types '
-              '-fdebug-prefix-map=/export/home01/buildbot_yocto/worker/morty_eotdrv2/build/eotdrv2/tmp/work/cortexa9hf-neon-jdsu-linux-gnueabi/python3/3.5.2-r1.0=/usr/src/debug/python3/3.5.2-r1.0 '
-              '-fdebug-prefix-map=/export/home01/buildbot_yocto/worker/morty_eotdrv2/build/eotdrv2/tmp/sysroots/x86_64-linux= '
-              '-fdebug-prefix-map=/export/home01/buildbot_yocto/worker/morty_eotdrv2/build/eotdrv2/tmp/sysroots/eotdrv2=',
+              '-fdebug-prefix-map=/mnt/Yocto/dev_morty/eotdrv2/tmp/work/cortexa9hf-neon-jdsu-linux-gnueabi/python3/3.5.2-r1.0=/usr/src/debug/python3/3.5.2-r1.0 '
+              '-fdebug-prefix-map=/mnt/Yocto/dev_morty/eotdrv2/tmp/sysroots/x86_64-linux= '
+              '-fdebug-prefix-map=/mnt/Yocto/dev_morty/eotdrv2/tmp/sysroots/eotdrv2=',
  'PY_CFLAGS_NODIST': '-Werror=declaration-after-statement',
  'PY_CORE_CFLAGS': '-Wno-unused-result -Wsign-compare -DNDEBUG -g  -O3 -Wall '
                    '-Wstrict-prototypes -O2 -pipe -g '
                    '-feliminate-unused-debug-types '
-                   '-fdebug-prefix-map=/export/home01/buildbot_yocto/worker/morty_eotdrv2/build/eotdrv2/tmp/work/cortexa9hf-neon-jdsu-linux-gnueabi/python3/3.5.2-r1.0=/usr/src/debug/python3/3.5.2-r1.0 '
-                   '-fdebug-prefix-map=/export/home01/buildbot_yocto/worker/morty_eotdrv2/build/eotdrv2/tmp/sysroots/x86_64-linux= '
-                   '-fdebug-prefix-map=/export/home01/buildbot_yocto/worker/morty_eotdrv2/build/eotdrv2/tmp/sysroots/eotdrv2=  '
+                   '-fdebug-prefix-map=/mnt/Yocto/dev_morty/eotdrv2/tmp/work/cortexa9hf-neon-jdsu-linux-gnueabi/python3/3.5.2-r1.0=/usr/src/debug/python3/3.5.2-r1.0 '
+                   '-fdebug-prefix-map=/mnt/Yocto/dev_morty/eotdrv2/tmp/sysroots/x86_64-linux= '
+                   '-fdebug-prefix-map=/mnt/Yocto/dev_morty/eotdrv2/tmp/sysroots/eotdrv2=  '
                    '-O2 -pipe -g -feliminate-unused-debug-types '
-                   '-fdebug-prefix-map=/export/home01/buildbot_yocto/worker/morty_eotdrv2/build/eotdrv2/tmp/work/cortexa9hf-neon-jdsu-linux-gnueabi/python3/3.5.2-r1.0=/usr/src/debug/python3/3.5.2-r1.0 '
-                   '-fdebug-prefix-map=/export/home01/buildbot_yocto/worker/morty_eotdrv2/build/eotdrv2/tmp/sysroots/x86_64-linux= '
-                   '-fdebug-prefix-map=/export/home01/buildbot_yocto/worker/morty_eotdrv2/build/eotdrv2/tmp/sysroots/eotdrv2= '
+                   '-fdebug-prefix-map=/mnt/Yocto/dev_morty/eotdrv2/tmp/work/cortexa9hf-neon-jdsu-linux-gnueabi/python3/3.5.2-r1.0=/usr/src/debug/python3/3.5.2-r1.0 '
+                   '-fdebug-prefix-map=/mnt/Yocto/dev_morty/eotdrv2/tmp/sysroots/x86_64-linux= '
+                   '-fdebug-prefix-map=/mnt/Yocto/dev_morty/eotdrv2/tmp/sysroots/eotdrv2= '
                    '-Werror=declaration-after-statement -I. -IInclude '
                    '-I../Python-3.5.2/Include -fPIC -DPy_BUILD_CORE',
  'PY_CPPFLAGS': '-I. -IInclude -I../Python-3.5.2/Include',
@@ -752,8 +752,8 @@ build_time_vars = {'ABIFLAGS': 'm',
  'WITH_VALGRIND': 0,
  'X87_DOUBLE_ROUNDING': 0,
  'XMLLIBSUBDIRS': 'xml xml/dom xml/etree xml/parsers xml/sax',
- 'abs_builddir': '/export/home01/buildbot_yocto/worker/morty_eotdrv2/build/eotdrv2/tmp/work/cortexa9hf-neon-jdsu-linux-gnueabi/python3/3.5.2-r1.0/build',
- 'abs_srcdir': '/export/home01/buildbot_yocto/worker/morty_eotdrv2/build/eotdrv2/tmp/work/cortexa9hf-neon-jdsu-linux-gnueabi/python3/3.5.2-r1.0/build/../Python-3.5.2',
+ 'abs_builddir': '/mnt/Yocto/dev_morty/eotdrv2/tmp/work/cortexa9hf-neon-jdsu-linux-gnueabi/python3/3.5.2-r1.0/build',
+ 'abs_srcdir': '/mnt/Yocto/dev_morty/eotdrv2/tmp/work/cortexa9hf-neon-jdsu-linux-gnueabi/python3/3.5.2-r1.0/build/../Python-3.5.2',
  'cross_compiling': 'yes',
  'datarootdir': '/usr/share',
  'exec_prefix': '/usr',
