@@ -45,6 +45,16 @@ PARTITION_8GB = [
     { 'type':'l', 'start':13581966, 'end':14942207, 'format':'ext4', 'label':'install', 'protected':False}  # -   (pmulti)
 ]
 
+PARTITION_7GB = [
+    { 'type':'p', 'start':    2048, 'end':   63487, 'format':'raw',                     'protected':True},  # 32MB (uboot zone + environment at offset 0x100000)
+    { 'type':'p', 'start':   63488, 'end':   96255, 'format':'ext4', 'label':'Cal',     'protected':True}, # 16MB (Cal)
+    { 'type':'p', 'start':   96256, 'end': 2193407, 'format':'ext4', 'label':'User',    'protected':True}, # 1GB  (User Disk)
+    { 'type':'x', 'start': 2193408, 'end':14195000, 'format':'raw'},  # - EXTENDED
+    { 'type':'l', 'start': 5193424, 'end': 9387677, 'format':'ext4', 'label':'FS1',     'protected':False}, # 2GB (Filesystem 1)
+    { 'type':'l', 'start': 9387696, 'end':13581949, 'format':'ext4', 'label':'FS2',     'protected':False}, # 2GB (Filesystem 2)
+    { 'type':'l', 'start':13581966, 'end':14195000, 'format':'ext4', 'label':'install', 'protected':False}  # -   (pmulti)
+]
+
 PARTITION_2GB = [
     { 'type':'p', 'start':       1, 'end':   65535, 'format':'raw',                     'protected':True},  # 32MB (uboot zone + environment at offset 0x100000)
     { 'type':'p', 'start':   65536, 'end':   98303, 'format':'ext4', 'label':'Cal',     'protected':True}, # 16MB (Cal)
@@ -66,10 +76,11 @@ def get_partition_plan():
         print("Warning: many emmc found when looking for patition plan, using the first one")
     size = get_blockdevice_size([*blk_device_list][0])
     print("Device has size of {}".format(size))
-    if size > 4096:
+    if size > 7300:
         return PARTITION_8GB
-    else:
-        return PARTITION_2GB
+    if size > 4096:
+        return PARTITION_7GB
+    return PARTITION_2GB
 
 
 # Return the size of a block device in Mo
